# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/inventory/rfid/LLRP.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.temporal import Instant_pb2 as opencannabis_dot_temporal_dot_Instant__pb2
from opencannabis.inventory.rfid import RFID_pb2 as opencannabis_dot_inventory_dot_rfid_dot_RFID__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/inventory/rfid/LLRP.proto',
  package='opencannabis.inventory.rfid',
  syntax='proto3',
  serialized_options=b'\n io.opencannabis.schema.inventoryH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&opencannabis/inventory/rfid/LLRP.proto\x12\x1bopencannabis.inventory.rfid\x1a\x19gust/core/datamodel.proto\x1a#opencannabis/temporal/Instant.proto\x1a&opencannabis/inventory/rfid/RFID.proto\"\xdc\x02\n\x0e\x42oundaryConfig\x12G\n\x05start\x18\x01 \x01(\x0b\x32\x38.opencannabis.inventory.rfid.BoundaryConfig.StartTrigger\x12\x45\n\x04stop\x18\x02 \x01(\x0b\x32\x37.opencannabis.inventory.rfid.BoundaryConfig.StopTrigger\x1a]\n\x0cStartTrigger\x12;\n\x04type\x18\x01 \x01(\x0e\x32-.opencannabis.inventory.rfid.StartTriggerType\x12\x10\n\x08schedule\x18\x02 \x01(\x04\x1a[\n\x0bStopTrigger\x12:\n\x04type\x18\x01 \x01(\x0e\x32,.opencannabis.inventory.rfid.StopTriggerType\x12\x10\n\x08schedule\x18\x02 \x01(\x04\"\x11\n\x0fReportingConfig\"\xa6\x01\n\x06ROSpec\x12\n\n\x02id\x18\x01 \x01(\r\x12\x10\n\x08priority\x18\x02 \x01(\r\x12=\n\x08\x62oundary\x18\x03 \x01(\x0b\x32+.opencannabis.inventory.rfid.BoundaryConfig\x12?\n\treporting\x18\x04 \x01(\x0b\x32,.opencannabis.inventory.rfid.ReportingConfig\"\xed\x02\n\x0fTagReportOrigin\x12\x86\x01\n\x06reader\x18\x01 \x01(\x0b\x32#.opencannabis.inventory.rfid.ReaderBQ\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03G\x12\x45\x44\x65scribes info about the RFID reader device involved in a tag report.\x12\x62\n\x07partner\x18\x02 \x01(\tBQ\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03G\x12\x45\x44\x65scribes the partner account to which the reader device is assigned.\x12m\n\x08location\x18\x03 \x01(\tB[\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03Q\x12ODescribes the location, owned by the partner, where the RFID reader is located.\"\xae\x07\n\tTagReport\x12\x91\x01\n\x07\x61ntenna\x18\x01 \x01(\x0b\x32$.opencannabis.inventory.rfid.AntennaBZ\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03P\x12NDescribes info, if available, about the RFID antenna involved in a tag report.\x12\x7f\n\x03tag\x18\x02 \x01(\x0b\x32 .opencannabis.inventory.rfid.TagBP\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03\x46\x12\x44Specifies information about the tag that was detected in this event.\x12X\n\x04rssi\x18\x03 \x01(\x01\x42J\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03@\x12>Relative Signal Strength indicator value for this tag reading.\x12\x97\x01\n\nfirst_seen\x18\x04 \x01(\x0b\x32\x1e.opencannabis.temporal.InstantBc\xda\xb5\x03\x02\x10\x01\xca\xb5\x03\x0b\x1a\tTIMESTAMP\xc2\xb5\x03J\x12HTimestamp describing when this tag was first seen by the RFID apparatus.\x12\x9b\x01\n\tlast_seen\x18\x05 \x01(\x0b\x32\x1e.opencannabis.temporal.InstantBh\xda\xb5\x03\x02\x10\x01\xca\xb5\x03\x0b\x1a\tTIMESTAMP\xc2\xb5\x03O\x12MTimestamp describing the last moment this tag was seen by the RFID apparatus.\x12\x93\x01\n\x08received\x18\x06 \x01(\x0b\x32\x1e.opencannabis.temporal.InstantBa\xda\xb5\x03\x02\x10\x01\xca\xb5\x03\x0b\x1a\tTIMESTAMP\xc2\xb5\x03H\x12\x46Timestamp describing when the edge engine received this reading event.\x12\x64\n\x05peers\x18\x07 \x01(\rBU\xc2\xb5\x03Q\x12ODescribes the count of tags read at the same moment, or in the same tag report.\"\x96\x02\n\x0cTagReportSet\x12\x93\x01\n\x06origin\x18\x01 \x01(\x0b\x32,.opencannabis.inventory.rfid.TagReportOriginBU\xc2\xb5\x03Q\x12OSpecifies the origin of this tag report, including the reader device and scope.\x12p\n\x06report\x18\x02 \x03(\x0b\x32&.opencannabis.inventory.rfid.TagReportB8\xc2\xb5\x03\x34\x12\x32\x44\x65scribes the tags seen in a given tag report set.*\xf9\x01\n\x14RegulatoryCapability\x12!\n\x1dUNSPECIFIED_REGULATORY_REGION\x10\x00\x12\n\n\x06US_FCC\x10\x01\x12\x10\n\x0c\x45TSI_302_208\x10\x02\x12\x10\n\x0c\x45TSI_300_220\x10\x03\x12\x15\n\x11\x41USTRALIA_LIPD_1W\x10\x04\x12\x15\n\x11\x41USTRALIA_LIPD_4W\x10\x05\x12\x16\n\x12JAPAN_ARIB_STD_T89\x10\x06\x12\x16\n\x12HONGKONG_OFTA_1049\x10\x07\x12\x15\n\x11TAIWAN_DGT_LP0002\x10\x08\x12\x19\n\x15KOREA_MIC_ARTICLE_5_2\x10\t*U\n\x10StartTriggerType\x12\x14\n\x10NO_START_TRIGGER\x10\x00\x12\r\n\tIMMEDIATE\x10\x01\x12\x0c\n\x08PERIODIC\x10\x02\x12\x0e\n\nGPIO_START\x10\x03*C\n\x0fStopTriggerType\x12\x13\n\x0fNO_STOP_TRIGGER\x10\x00\x12\x0c\n\x08\x44URATION\x10\x01\x12\r\n\tGPIO_STOP\x10\x02\x42,\n io.opencannabis.schema.inventoryH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_temporal_dot_Instant__pb2.DESCRIPTOR,opencannabis_dot_inventory_dot_rfid_dot_RFID__pb2.DESCRIPTOR,])

_REGULATORYCAPABILITY = _descriptor.EnumDescriptor(
  name='RegulatoryCapability',
  full_name='opencannabis.inventory.rfid.RegulatoryCapability',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_REGULATORY_REGION', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='US_FCC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ETSI_302_208', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ETSI_300_220', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUSTRALIA_LIPD_1W', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUSTRALIA_LIPD_4W', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JAPAN_ARIB_STD_T89', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HONGKONG_OFTA_1049', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TAIWAN_DGT_LP0002', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KOREA_MIC_ARTICLE_5_2', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2309,
  serialized_end=2558,
)
_sym_db.RegisterEnumDescriptor(_REGULATORYCAPABILITY)

RegulatoryCapability = enum_type_wrapper.EnumTypeWrapper(_REGULATORYCAPABILITY)
_STARTTRIGGERTYPE = _descriptor.EnumDescriptor(
  name='StartTriggerType',
  full_name='opencannabis.inventory.rfid.StartTriggerType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_START_TRIGGER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMMEDIATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERIODIC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GPIO_START', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2560,
  serialized_end=2645,
)
_sym_db.RegisterEnumDescriptor(_STARTTRIGGERTYPE)

StartTriggerType = enum_type_wrapper.EnumTypeWrapper(_STARTTRIGGERTYPE)
_STOPTRIGGERTYPE = _descriptor.EnumDescriptor(
  name='StopTriggerType',
  full_name='opencannabis.inventory.rfid.StopTriggerType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_STOP_TRIGGER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DURATION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GPIO_STOP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2647,
  serialized_end=2714,
)
_sym_db.RegisterEnumDescriptor(_STOPTRIGGERTYPE)

StopTriggerType = enum_type_wrapper.EnumTypeWrapper(_STOPTRIGGERTYPE)
UNSPECIFIED_REGULATORY_REGION = 0
US_FCC = 1
ETSI_302_208 = 2
ETSI_300_220 = 3
AUSTRALIA_LIPD_1W = 4
AUSTRALIA_LIPD_4W = 5
JAPAN_ARIB_STD_T89 = 6
HONGKONG_OFTA_1049 = 7
TAIWAN_DGT_LP0002 = 8
KOREA_MIC_ARTICLE_5_2 = 9
NO_START_TRIGGER = 0
IMMEDIATE = 1
PERIODIC = 2
GPIO_START = 3
NO_STOP_TRIGGER = 0
DURATION = 1
GPIO_STOP = 2



_BOUNDARYCONFIG_STARTTRIGGER = _descriptor.Descriptor(
  name='StartTrigger',
  full_name='opencannabis.inventory.rfid.BoundaryConfig.StartTrigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.inventory.rfid.BoundaryConfig.StartTrigger.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schedule', full_name='opencannabis.inventory.rfid.BoundaryConfig.StartTrigger.schedule', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=431,
)

_BOUNDARYCONFIG_STOPTRIGGER = _descriptor.Descriptor(
  name='StopTrigger',
  full_name='opencannabis.inventory.rfid.BoundaryConfig.StopTrigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.inventory.rfid.BoundaryConfig.StopTrigger.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schedule', full_name='opencannabis.inventory.rfid.BoundaryConfig.StopTrigger.schedule', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=433,
  serialized_end=524,
)

_BOUNDARYCONFIG = _descriptor.Descriptor(
  name='BoundaryConfig',
  full_name='opencannabis.inventory.rfid.BoundaryConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='opencannabis.inventory.rfid.BoundaryConfig.start', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop', full_name='opencannabis.inventory.rfid.BoundaryConfig.stop', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BOUNDARYCONFIG_STARTTRIGGER, _BOUNDARYCONFIG_STOPTRIGGER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=524,
)


_REPORTINGCONFIG = _descriptor.Descriptor(
  name='ReportingConfig',
  full_name='opencannabis.inventory.rfid.ReportingConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=526,
  serialized_end=543,
)


_ROSPEC = _descriptor.Descriptor(
  name='ROSpec',
  full_name='opencannabis.inventory.rfid.ROSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='opencannabis.inventory.rfid.ROSpec.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='opencannabis.inventory.rfid.ROSpec.priority', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boundary', full_name='opencannabis.inventory.rfid.ROSpec.boundary', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reporting', full_name='opencannabis.inventory.rfid.ROSpec.reporting', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=546,
  serialized_end=712,
)


_TAGREPORTORIGIN = _descriptor.Descriptor(
  name='TagReportOrigin',
  full_name='opencannabis.inventory.rfid.TagReportOrigin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reader', full_name='opencannabis.inventory.rfid.TagReportOrigin.reader', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003G\022EDescribes info about the RFID reader device involved in a tag report.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partner', full_name='opencannabis.inventory.rfid.TagReportOrigin.partner', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003G\022EDescribes the partner account to which the reader device is assigned.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='opencannabis.inventory.rfid.TagReportOrigin.location', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003Q\022ODescribes the location, owned by the partner, where the RFID reader is located.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=715,
  serialized_end=1080,
)


_TAGREPORT = _descriptor.Descriptor(
  name='TagReport',
  full_name='opencannabis.inventory.rfid.TagReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='antenna', full_name='opencannabis.inventory.rfid.TagReport.antenna', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003P\022NDescribes info, if available, about the RFID antenna involved in a tag report.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tag', full_name='opencannabis.inventory.rfid.TagReport.tag', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003F\022DSpecifies information about the tag that was detected in this event.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rssi', full_name='opencannabis.inventory.rfid.TagReport.rssi', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003@\022>Relative Signal Strength indicator value for this tag reading.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first_seen', full_name='opencannabis.inventory.rfid.TagReport.first_seen', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\312\265\003\013\032\tTIMESTAMP\302\265\003J\022HTimestamp describing when this tag was first seen by the RFID apparatus.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_seen', full_name='opencannabis.inventory.rfid.TagReport.last_seen', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\312\265\003\013\032\tTIMESTAMP\302\265\003O\022MTimestamp describing the last moment this tag was seen by the RFID apparatus.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='received', full_name='opencannabis.inventory.rfid.TagReport.received', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\312\265\003\013\032\tTIMESTAMP\302\265\003H\022FTimestamp describing when the edge engine received this reading event.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peers', full_name='opencannabis.inventory.rfid.TagReport.peers', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003Q\022ODescribes the count of tags read at the same moment, or in the same tag report.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1083,
  serialized_end=2025,
)


_TAGREPORTSET = _descriptor.Descriptor(
  name='TagReportSet',
  full_name='opencannabis.inventory.rfid.TagReportSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='opencannabis.inventory.rfid.TagReportSet.origin', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003Q\022OSpecifies the origin of this tag report, including the reader device and scope.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='report', full_name='opencannabis.inventory.rfid.TagReportSet.report', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0034\0222Describes the tags seen in a given tag report set.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2028,
  serialized_end=2306,
)

_BOUNDARYCONFIG_STARTTRIGGER.fields_by_name['type'].enum_type = _STARTTRIGGERTYPE
_BOUNDARYCONFIG_STARTTRIGGER.containing_type = _BOUNDARYCONFIG
_BOUNDARYCONFIG_STOPTRIGGER.fields_by_name['type'].enum_type = _STOPTRIGGERTYPE
_BOUNDARYCONFIG_STOPTRIGGER.containing_type = _BOUNDARYCONFIG
_BOUNDARYCONFIG.fields_by_name['start'].message_type = _BOUNDARYCONFIG_STARTTRIGGER
_BOUNDARYCONFIG.fields_by_name['stop'].message_type = _BOUNDARYCONFIG_STOPTRIGGER
_ROSPEC.fields_by_name['boundary'].message_type = _BOUNDARYCONFIG
_ROSPEC.fields_by_name['reporting'].message_type = _REPORTINGCONFIG
_TAGREPORTORIGIN.fields_by_name['reader'].message_type = opencannabis_dot_inventory_dot_rfid_dot_RFID__pb2._READER
_TAGREPORT.fields_by_name['antenna'].message_type = opencannabis_dot_inventory_dot_rfid_dot_RFID__pb2._ANTENNA
_TAGREPORT.fields_by_name['tag'].message_type = opencannabis_dot_inventory_dot_rfid_dot_RFID__pb2._TAG
_TAGREPORT.fields_by_name['first_seen'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_TAGREPORT.fields_by_name['last_seen'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_TAGREPORT.fields_by_name['received'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_TAGREPORTSET.fields_by_name['origin'].message_type = _TAGREPORTORIGIN
_TAGREPORTSET.fields_by_name['report'].message_type = _TAGREPORT
DESCRIPTOR.message_types_by_name['BoundaryConfig'] = _BOUNDARYCONFIG
DESCRIPTOR.message_types_by_name['ReportingConfig'] = _REPORTINGCONFIG
DESCRIPTOR.message_types_by_name['ROSpec'] = _ROSPEC
DESCRIPTOR.message_types_by_name['TagReportOrigin'] = _TAGREPORTORIGIN
DESCRIPTOR.message_types_by_name['TagReport'] = _TAGREPORT
DESCRIPTOR.message_types_by_name['TagReportSet'] = _TAGREPORTSET
DESCRIPTOR.enum_types_by_name['RegulatoryCapability'] = _REGULATORYCAPABILITY
DESCRIPTOR.enum_types_by_name['StartTriggerType'] = _STARTTRIGGERTYPE
DESCRIPTOR.enum_types_by_name['StopTriggerType'] = _STOPTRIGGERTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BoundaryConfig = _reflection.GeneratedProtocolMessageType('BoundaryConfig', (_message.Message,), {

  'StartTrigger' : _reflection.GeneratedProtocolMessageType('StartTrigger', (_message.Message,), {
    'DESCRIPTOR' : _BOUNDARYCONFIG_STARTTRIGGER,
    '__module__' : 'opencannabis.inventory.rfid.LLRP_pb2'
    # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.BoundaryConfig.StartTrigger)
    })
  ,

  'StopTrigger' : _reflection.GeneratedProtocolMessageType('StopTrigger', (_message.Message,), {
    'DESCRIPTOR' : _BOUNDARYCONFIG_STOPTRIGGER,
    '__module__' : 'opencannabis.inventory.rfid.LLRP_pb2'
    # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.BoundaryConfig.StopTrigger)
    })
  ,
  'DESCRIPTOR' : _BOUNDARYCONFIG,
  '__module__' : 'opencannabis.inventory.rfid.LLRP_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.BoundaryConfig)
  })
_sym_db.RegisterMessage(BoundaryConfig)
_sym_db.RegisterMessage(BoundaryConfig.StartTrigger)
_sym_db.RegisterMessage(BoundaryConfig.StopTrigger)

ReportingConfig = _reflection.GeneratedProtocolMessageType('ReportingConfig', (_message.Message,), {
  'DESCRIPTOR' : _REPORTINGCONFIG,
  '__module__' : 'opencannabis.inventory.rfid.LLRP_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.ReportingConfig)
  })
_sym_db.RegisterMessage(ReportingConfig)

ROSpec = _reflection.GeneratedProtocolMessageType('ROSpec', (_message.Message,), {
  'DESCRIPTOR' : _ROSPEC,
  '__module__' : 'opencannabis.inventory.rfid.LLRP_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.ROSpec)
  })
_sym_db.RegisterMessage(ROSpec)

TagReportOrigin = _reflection.GeneratedProtocolMessageType('TagReportOrigin', (_message.Message,), {
  'DESCRIPTOR' : _TAGREPORTORIGIN,
  '__module__' : 'opencannabis.inventory.rfid.LLRP_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.TagReportOrigin)
  })
_sym_db.RegisterMessage(TagReportOrigin)

TagReport = _reflection.GeneratedProtocolMessageType('TagReport', (_message.Message,), {
  'DESCRIPTOR' : _TAGREPORT,
  '__module__' : 'opencannabis.inventory.rfid.LLRP_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.TagReport)
  })
_sym_db.RegisterMessage(TagReport)

TagReportSet = _reflection.GeneratedProtocolMessageType('TagReportSet', (_message.Message,), {
  'DESCRIPTOR' : _TAGREPORTSET,
  '__module__' : 'opencannabis.inventory.rfid.LLRP_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.TagReportSet)
  })
_sym_db.RegisterMessage(TagReportSet)


DESCRIPTOR._options = None
_TAGREPORTORIGIN.fields_by_name['reader']._options = None
_TAGREPORTORIGIN.fields_by_name['partner']._options = None
_TAGREPORTORIGIN.fields_by_name['location']._options = None
_TAGREPORT.fields_by_name['antenna']._options = None
_TAGREPORT.fields_by_name['tag']._options = None
_TAGREPORT.fields_by_name['rssi']._options = None
_TAGREPORT.fields_by_name['first_seen']._options = None
_TAGREPORT.fields_by_name['last_seen']._options = None
_TAGREPORT.fields_by_name['received']._options = None
_TAGREPORT.fields_by_name['peers']._options = None
_TAGREPORTSET.fields_by_name['origin']._options = None
_TAGREPORTSET.fields_by_name['report']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/oauth/AuthorizationScope.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/oauth/AuthorizationScope.proto',
  package='opencannabis.oauth',
  syntax='proto3',
  serialized_options=b'\n\034io.opencannabis.schema.oauthH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+opencannabis/oauth/AuthorizationScope.proto\x12\x12opencannabis.oauth\"J\n\x12\x41uthorizationScope\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\tB(\n\x1cio.opencannabis.schema.oauthH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
)




_AUTHORIZATIONSCOPE = _descriptor.Descriptor(
  name='AuthorizationScope',
  full_name='opencannabis.oauth.AuthorizationScope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='opencannabis.oauth.AuthorizationScope.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='opencannabis.oauth.AuthorizationScope.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='opencannabis.oauth.AuthorizationScope.uri', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='icon', full_name='opencannabis.oauth.AuthorizationScope.icon', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=141,
)

DESCRIPTOR.message_types_by_name['AuthorizationScope'] = _AUTHORIZATIONSCOPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AuthorizationScope = _reflection.GeneratedProtocolMessageType('AuthorizationScope', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZATIONSCOPE,
  '__module__' : 'opencannabis.oauth.AuthorizationScope_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.oauth.AuthorizationScope)
  })
_sym_db.RegisterMessage(AuthorizationScope)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/temporal/Interval.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/temporal/Interval.proto',
  package='opencannabis.temporal',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.temporalB\020TemporalIntervalH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$opencannabis/temporal/Interval.proto\x12\x15opencannabis.temporal\x1a\x19gust/core/datamodel.proto\"\xd8\x01\n\x0cTimeInterval\x12i\n\x08interval\x18\x01 \x01(\x0e\x32\x1f.opencannabis.temporal.IntervalB6\xc2\xb5\x03\x32\x12\x30Specifies the type/window for the time interval.\x12]\n\x05\x65very\x18\x02 \x01(\rBN\xc2\xb5\x03J\x12HSpecifies an optional interval border, i.e., the N in \'every N seconds\'.*H\n\x08Interval\x12\x0c\n\x08MINUTELY\x10\x00\x12\n\n\x06HOURLY\x10\x01\x12\t\n\x05\x44\x41ILY\x10\x02\x12\n\n\x06WEEKLY\x10\x03\x12\x0b\n\x07MONTHLY\x10\x04\x42=\n\x1fio.opencannabis.schema.temporalB\x10TemporalIntervalH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])

_INTERVAL = _descriptor.EnumDescriptor(
  name='Interval',
  full_name='opencannabis.temporal.Interval',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MINUTELY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOURLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DAILY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WEEKLY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONTHLY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=309,
  serialized_end=381,
)
_sym_db.RegisterEnumDescriptor(_INTERVAL)

Interval = enum_type_wrapper.EnumTypeWrapper(_INTERVAL)
MINUTELY = 0
HOURLY = 1
DAILY = 2
WEEKLY = 3
MONTHLY = 4



_TIMEINTERVAL = _descriptor.Descriptor(
  name='TimeInterval',
  full_name='opencannabis.temporal.TimeInterval',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interval', full_name='opencannabis.temporal.TimeInterval.interval', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0032\0220Specifies the type/window for the time interval.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='every', full_name='opencannabis.temporal.TimeInterval.every', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003J\022HSpecifies an optional interval border, i.e., the N in \'every N seconds\'.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=307,
)

_TIMEINTERVAL.fields_by_name['interval'].enum_type = _INTERVAL
DESCRIPTOR.message_types_by_name['TimeInterval'] = _TIMEINTERVAL
DESCRIPTOR.enum_types_by_name['Interval'] = _INTERVAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TimeInterval = _reflection.GeneratedProtocolMessageType('TimeInterval', (_message.Message,), {
  'DESCRIPTOR' : _TIMEINTERVAL,
  '__module__' : 'opencannabis.temporal.Interval_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.temporal.TimeInterval)
  })
_sym_db.RegisterMessage(TimeInterval)


DESCRIPTOR._options = None
_TIMEINTERVAL.fields_by_name['interval']._options = None
_TIMEINTERVAL.fields_by_name['every']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/media/MediaType.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/media/MediaType.proto',
  package='opencannabis.media',
  syntax='proto3',
  serialized_options=b'\n\034io.opencannabis.schema.mediaB\rMediaItemTypeH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"opencannabis/media/MediaType.proto\x12\x12opencannabis.media\x1a\x19gust/core/datamodel.proto\"\xcc\x06\n\tMediaType\x12x\n\x04kind\x18\x01 \x01(\x0e\x32\".opencannabis.media.MediaType.KindBF\xc2\xb5\x03\x42\x12@Specifies the generic kind of media being described or attached.\x12u\n\nimage_type\x18\x65 \x01(\x0e\x32\'.opencannabis.media.MediaType.ImageKindB6\xc2\xb5\x03\x32\x12\x30Specifies content for an image-based media item.H\x00\x12~\n\rdocument_type\x18\xc9\x01 \x01(\x0e\x32*.opencannabis.media.MediaType.DocumentKindB8\xc2\xb5\x03\x34\x12\x32Specifies content for a document-based media item.H\x00\x12u\n\nvideo_type\x18\xad\x02 \x01(\x0e\x32\'.opencannabis.media.MediaType.VideoKindB5\xc2\xb5\x03\x31\x12/Specifies content for a video-based media item.H\x00\"4\n\x04Kind\x12\x08\n\x04LINK\x10\x00\x12\t\n\x05IMAGE\x10\x01\x12\x0c\n\x08\x44OCUMENT\x10\x02\x12\t\n\x05VIDEO\x10\x03\"U\n\tImageKind\x12\x1a\n\x16UNSPECIFIED_IMAGE_TYPE\x10\x00\x12\x07\n\x03PNG\x10\x01\x12\x07\n\x03JPG\x10\x02\x12\x07\n\x03GIF\x10\x03\x12\x07\n\x03SVG\x10\x04\x12\x08\n\x04WEBP\x10\x05\"\"\n\x08ImageDPI\x12\x06\n\x02X1\x10\x00\x12\x06\n\x02X2\x10\x01\x12\x06\n\x02X3\x10\x02\"W\n\x0c\x44ocumentKind\x12\x1d\n\x19UNSPECIFIED_DOCUMENT_TYPE\x10\x00\x12\x07\n\x03TXT\x10\x01\x12\x08\n\x04HTML\x10\x02\x12\x07\n\x03PDF\x10\x03\x12\x0c\n\x08MARKDOWN\x10\x04\"B\n\tVideoKind\x12\x1a\n\x16UNSPECIFIED_VIDEO_TYPE\x10\x00\x12\x07\n\x03MP4\x10\x01\x12\x07\n\x03\x46LV\x10\x02\x12\x07\n\x03HLS\x10\x03\x42\t\n\x07\x63ontentB7\n\x1cio.opencannabis.schema.mediaB\rMediaItemTypeH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])



_MEDIATYPE_KIND = _descriptor.EnumDescriptor(
  name='Kind',
  full_name='opencannabis.media.MediaType.Kind',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LINK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMAGE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOCUMENT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIDEO', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=587,
  serialized_end=639,
)
_sym_db.RegisterEnumDescriptor(_MEDIATYPE_KIND)

_MEDIATYPE_IMAGEKIND = _descriptor.EnumDescriptor(
  name='ImageKind',
  full_name='opencannabis.media.MediaType.ImageKind',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_IMAGE_TYPE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PNG', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JPG', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GIF', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SVG', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WEBP', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=641,
  serialized_end=726,
)
_sym_db.RegisterEnumDescriptor(_MEDIATYPE_IMAGEKIND)

_MEDIATYPE_IMAGEDPI = _descriptor.EnumDescriptor(
  name='ImageDPI',
  full_name='opencannabis.media.MediaType.ImageDPI',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='X1', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='X2', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='X3', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=728,
  serialized_end=762,
)
_sym_db.RegisterEnumDescriptor(_MEDIATYPE_IMAGEDPI)

_MEDIATYPE_DOCUMENTKIND = _descriptor.EnumDescriptor(
  name='DocumentKind',
  full_name='opencannabis.media.MediaType.DocumentKind',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_DOCUMENT_TYPE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TXT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTML', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PDF', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MARKDOWN', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=764,
  serialized_end=851,
)
_sym_db.RegisterEnumDescriptor(_MEDIATYPE_DOCUMENTKIND)

_MEDIATYPE_VIDEOKIND = _descriptor.EnumDescriptor(
  name='VideoKind',
  full_name='opencannabis.media.MediaType.VideoKind',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_VIDEO_TYPE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MP4', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLV', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HLS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=853,
  serialized_end=919,
)
_sym_db.RegisterEnumDescriptor(_MEDIATYPE_VIDEOKIND)


_MEDIATYPE = _descriptor.Descriptor(
  name='MediaType',
  full_name='opencannabis.media.MediaType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='opencannabis.media.MediaType.kind', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003B\022@Specifies the generic kind of media being described or attached.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_type', full_name='opencannabis.media.MediaType.image_type', index=1,
      number=101, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0032\0220Specifies content for an image-based media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='document_type', full_name='opencannabis.media.MediaType.document_type', index=2,
      number=201, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0034\0222Specifies content for a document-based media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='video_type', full_name='opencannabis.media.MediaType.video_type', index=3,
      number=301, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0031\022/Specifies content for a video-based media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MEDIATYPE_KIND,
    _MEDIATYPE_IMAGEKIND,
    _MEDIATYPE_IMAGEDPI,
    _MEDIATYPE_DOCUMENTKIND,
    _MEDIATYPE_VIDEOKIND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='opencannabis.media.MediaType.content',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=86,
  serialized_end=930,
)

_MEDIATYPE.fields_by_name['kind'].enum_type = _MEDIATYPE_KIND
_MEDIATYPE.fields_by_name['image_type'].enum_type = _MEDIATYPE_IMAGEKIND
_MEDIATYPE.fields_by_name['document_type'].enum_type = _MEDIATYPE_DOCUMENTKIND
_MEDIATYPE.fields_by_name['video_type'].enum_type = _MEDIATYPE_VIDEOKIND
_MEDIATYPE_KIND.containing_type = _MEDIATYPE
_MEDIATYPE_IMAGEKIND.containing_type = _MEDIATYPE
_MEDIATYPE_IMAGEDPI.containing_type = _MEDIATYPE
_MEDIATYPE_DOCUMENTKIND.containing_type = _MEDIATYPE
_MEDIATYPE_VIDEOKIND.containing_type = _MEDIATYPE
_MEDIATYPE.oneofs_by_name['content'].fields.append(
  _MEDIATYPE.fields_by_name['image_type'])
_MEDIATYPE.fields_by_name['image_type'].containing_oneof = _MEDIATYPE.oneofs_by_name['content']
_MEDIATYPE.oneofs_by_name['content'].fields.append(
  _MEDIATYPE.fields_by_name['document_type'])
_MEDIATYPE.fields_by_name['document_type'].containing_oneof = _MEDIATYPE.oneofs_by_name['content']
_MEDIATYPE.oneofs_by_name['content'].fields.append(
  _MEDIATYPE.fields_by_name['video_type'])
_MEDIATYPE.fields_by_name['video_type'].containing_oneof = _MEDIATYPE.oneofs_by_name['content']
DESCRIPTOR.message_types_by_name['MediaType'] = _MEDIATYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MediaType = _reflection.GeneratedProtocolMessageType('MediaType', (_message.Message,), {
  'DESCRIPTOR' : _MEDIATYPE,
  '__module__' : 'opencannabis.media.MediaType_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.media.MediaType)
  })
_sym_db.RegisterMessage(MediaType)


DESCRIPTOR._options = None
_MEDIATYPE.fields_by_name['kind']._options = None
_MEDIATYPE.fields_by_name['image_type']._options = None
_MEDIATYPE.fields_by_name['document_type']._options = None
_MEDIATYPE.fields_by_name['video_type']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/content/MaterialsData.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.structs import Grow_pb2 as opencannabis_dot_structs_dot_Grow__pb2
from opencannabis.structs import Shelf_pb2 as opencannabis_dot_structs_dot_Shelf__pb2
from opencannabis.structs import Species_pb2 as opencannabis_dot_structs_dot_Species__pb2
from opencannabis.structs import Genetics_pb2 as opencannabis_dot_structs_dot_Genetics__pb2
from opencannabis.products.distribution import DistributionChannel_pb2 as opencannabis_dot_products_dot_distribution_dot_DistributionChannel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/content/MaterialsData.proto',
  package='opencannabis.content',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.contentB\020MaterialsContentH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(opencannabis/content/MaterialsData.proto\x12\x14opencannabis.content\x1a\x1fopencannabis/structs/Grow.proto\x1a opencannabis/structs/Shelf.proto\x1a\"opencannabis/structs/Species.proto\x1a#opencannabis/structs/Genetics.proto\x1a<opencannabis/products/distribution/DistributionChannel.proto\"\x90\x02\n\rMaterialsData\x12.\n\x07species\x18\x01 \x01(\x0e\x32\x1d.opencannabis.structs.Species\x12\x30\n\x08genetics\x18\x02 \x01(\x0b\x32\x1e.opencannabis.structs.Genetics\x12(\n\x04grow\x18\x03 \x01(\x0e\x32\x1a.opencannabis.structs.Grow\x12*\n\x05shelf\x18\x04 \x01(\x0e\x32\x1b.opencannabis.structs.Shelf\x12G\n\x07\x63hannel\x18\x05 \x03(\x0b\x32\x36.opencannabis.products.distribution.DistributionPolicyB<\n\x1eio.opencannabis.schema.contentB\x10MaterialsContentH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_structs_dot_Grow__pb2.DESCRIPTOR,opencannabis_dot_structs_dot_Shelf__pb2.DESCRIPTOR,opencannabis_dot_structs_dot_Species__pb2.DESCRIPTOR,opencannabis_dot_structs_dot_Genetics__pb2.DESCRIPTOR,opencannabis_dot_products_dot_distribution_dot_DistributionChannel__pb2.DESCRIPTOR,])




_MATERIALSDATA = _descriptor.Descriptor(
  name='MaterialsData',
  full_name='opencannabis.content.MaterialsData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='species', full_name='opencannabis.content.MaterialsData.species', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='genetics', full_name='opencannabis.content.MaterialsData.genetics', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grow', full_name='opencannabis.content.MaterialsData.grow', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shelf', full_name='opencannabis.content.MaterialsData.shelf', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel', full_name='opencannabis.content.MaterialsData.channel', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=269,
  serialized_end=541,
)

_MATERIALSDATA.fields_by_name['species'].enum_type = opencannabis_dot_structs_dot_Species__pb2._SPECIES
_MATERIALSDATA.fields_by_name['genetics'].message_type = opencannabis_dot_structs_dot_Genetics__pb2._GENETICS
_MATERIALSDATA.fields_by_name['grow'].enum_type = opencannabis_dot_structs_dot_Grow__pb2._GROW
_MATERIALSDATA.fields_by_name['shelf'].enum_type = opencannabis_dot_structs_dot_Shelf__pb2._SHELF
_MATERIALSDATA.fields_by_name['channel'].message_type = opencannabis_dot_products_dot_distribution_dot_DistributionChannel__pb2._DISTRIBUTIONPOLICY
DESCRIPTOR.message_types_by_name['MaterialsData'] = _MATERIALSDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MaterialsData = _reflection.GeneratedProtocolMessageType('MaterialsData', (_message.Message,), {
  'DESCRIPTOR' : _MATERIALSDATA,
  '__module__' : 'opencannabis.content.MaterialsData_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.MaterialsData)
  })
_sym_db.RegisterMessage(MaterialsData)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/geo/Country.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/geo/Country.proto',
  package='opencannabis.geo',
  syntax='proto3',
  serialized_options=b'\n\032io.opencannabis.schema.geoH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1eopencannabis/geo/Country.proto\x12\x10opencannabis.geo\"\x17\n\x07\x43ountry\x12\x0c\n\x04\x63ode\x18\x01 \x01(\tB&\n\x1aio.opencannabis.schema.geoH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
)




_COUNTRY = _descriptor.Descriptor(
  name='Country',
  full_name='opencannabis.geo.Country',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='opencannabis.geo.Country.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=75,
)

DESCRIPTOR.message_types_by_name['Country'] = _COUNTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Country = _reflection.GeneratedProtocolMessageType('Country', (_message.Message,), {
  'DESCRIPTOR' : _COUNTRY,
  '__module__' : 'opencannabis.geo.Country_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.geo.Country)
  })
_sym_db.RegisterMessage(Country)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/structs/Version.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/structs/Version.proto',
  package='opencannabis.structs',
  syntax='proto3',
  serialized_options=b'\n\035io.opencannabis.schema.structB\007VersionH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"opencannabis/structs/Version.proto\x12\x14opencannabis.structs\x1a\x19gust/core/datamodel.proto\"Q\n\x0bVersionSpec\x12:\n\x04name\x18\x01 \x01(\tB*\xc2\xb5\x03&\x12$Version specified by arbitrary name.H\x00\x42\x06\n\x04specB2\n\x1dio.opencannabis.schema.structB\x07VersionH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])




_VERSIONSPEC = _descriptor.Descriptor(
  name='VersionSpec',
  full_name='opencannabis.structs.VersionSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.structs.VersionSpec.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003&\022$Version specified by arbitrary name.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='spec', full_name='opencannabis.structs.VersionSpec.spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=87,
  serialized_end=168,
)

_VERSIONSPEC.oneofs_by_name['spec'].fields.append(
  _VERSIONSPEC.fields_by_name['name'])
_VERSIONSPEC.fields_by_name['name'].containing_oneof = _VERSIONSPEC.oneofs_by_name['spec']
DESCRIPTOR.message_types_by_name['VersionSpec'] = _VERSIONSPEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VersionSpec = _reflection.GeneratedProtocolMessageType('VersionSpec', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONSPEC,
  '__module__' : 'opencannabis.structs.Version_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.structs.VersionSpec)
  })
_sym_db.RegisterMessage(VersionSpec)


DESCRIPTOR._options = None
_VERSIONSPEC.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/structs/Grow.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/structs/Grow.proto',
  package='opencannabis.structs',
  syntax='proto3',
  serialized_options=b'\n%io.opencannabis.schema.product.structB\014MaterialGrowH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fopencannabis/structs/Grow.proto\x12\x14opencannabis.structs*<\n\x04Grow\x12\x0b\n\x07GENERIC\x10\x00\x12\n\n\x06INDOOR\x10\x01\x12\x0e\n\nGREENHOUSE\x10\x02\x12\x0b\n\x07OUTDOOR\x10\x03\x42?\n%io.opencannabis.schema.product.structB\x0cMaterialGrowH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
)

_GROW = _descriptor.EnumDescriptor(
  name='Grow',
  full_name='opencannabis.structs.Grow',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GENERIC', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INDOOR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREENHOUSE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTDOOR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=57,
  serialized_end=117,
)
_sym_db.RegisterEnumDescriptor(_GROW)

Grow = enum_type_wrapper.EnumTypeWrapper(_GROW)
GENERIC = 0
INDOOR = 1
GREENHOUSE = 2
OUTDOOR = 3


DESCRIPTOR.enum_types_by_name['Grow'] = _GROW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/structs/labtesting/Cannabinoids.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/structs/labtesting/Cannabinoids.proto',
  package='opencannabis.structs.labtesting',
  syntax='proto3',
  serialized_options=b'\n-io.opencannabis.schema.product.struct.testingB\024CannabinoidCompoundsH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2opencannabis/structs/labtesting/Cannabinoids.proto\x12\x1fopencannabis.structs.labtesting*\xe6\x01\n\x0b\x43\x61nnabinoid\x12\x07\n\x03THC\x10\x00\x12\t\n\x05THC_A\x10\x01\x12\t\n\x05THC_V\x10\x02\x12\n\n\x06THC_VA\x10\x03\x12\t\n\x05THC_8\x10\x04\x12\t\n\x05THC_9\x10\x05\x12\x07\n\x03\x43\x42\x44\x10\n\x12\t\n\x05\x43\x42\x44_A\x10\x0b\x12\t\n\x05\x43\x42\x44_V\x10\x0c\x12\n\n\x06\x43\x42\x44_VA\x10\r\x12\x07\n\x03\x43\x42\x43\x10\x14\x12\t\n\x05\x43\x42\x43_A\x10\x15\x12\x07\n\x03\x43\x42G\x10\x1e\x12\t\n\x05\x43\x42G_A\x10\x1f\x12\x07\n\x03\x43\x42N\x10(\x12\t\n\x05\x43\x42N_A\x10)\x12\x07\n\x03\x43\x42V\x10\x32\x12\t\n\x05\x43\x42V_A\x10\x33\x12\x07\n\x03TAC\x10<\x12\x07\n\x03\x43\x42L\x10\x46\x12\t\n\x05\x43\x42L_A\x10G*|\n\x10\x43\x61nnabinoidRatio\x12\x1d\n\x19NO_CANNABINOID_PREFERENCE\x10\x00\x12\x0c\n\x08THC_ONLY\x10\x01\x12\x10\n\x0cTHC_OVER_CBD\x10\x02\x12\t\n\x05\x45QUAL\x10\x03\x12\x10\n\x0c\x43\x42\x44_OVER_THC\x10\x04\x12\x0c\n\x08\x43\x42\x44_ONLY\x10\x05\x42O\n-io.opencannabis.schema.product.struct.testingB\x14\x43\x61nnabinoidCompoundsH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
)

_CANNABINOID = _descriptor.EnumDescriptor(
  name='Cannabinoid',
  full_name='opencannabis.structs.labtesting.Cannabinoid',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='THC', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THC_A', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THC_V', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THC_VA', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THC_8', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THC_9', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBD', index=6, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBD_A', index=7, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBD_V', index=8, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBD_VA', index=9, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBC', index=10, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBC_A', index=11, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBG', index=12, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBG_A', index=13, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBN', index=14, number=40,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBN_A', index=15, number=41,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBV', index=16, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBV_A', index=17, number=51,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TAC', index=18, number=60,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBL', index=19, number=70,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBL_A', index=20, number=71,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=88,
  serialized_end=318,
)
_sym_db.RegisterEnumDescriptor(_CANNABINOID)

Cannabinoid = enum_type_wrapper.EnumTypeWrapper(_CANNABINOID)
_CANNABINOIDRATIO = _descriptor.EnumDescriptor(
  name='CannabinoidRatio',
  full_name='opencannabis.structs.labtesting.CannabinoidRatio',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_CANNABINOID_PREFERENCE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THC_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THC_OVER_CBD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBD_OVER_THC', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBD_ONLY', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=320,
  serialized_end=444,
)
_sym_db.RegisterEnumDescriptor(_CANNABINOIDRATIO)

CannabinoidRatio = enum_type_wrapper.EnumTypeWrapper(_CANNABINOIDRATIO)
THC = 0
THC_A = 1
THC_V = 2
THC_VA = 3
THC_8 = 4
THC_9 = 5
CBD = 10
CBD_A = 11
CBD_V = 12
CBD_VA = 13
CBC = 20
CBC_A = 21
CBG = 30
CBG_A = 31
CBN = 40
CBN_A = 41
CBV = 50
CBV_A = 51
TAC = 60
CBL = 70
CBL_A = 71
NO_CANNABINOID_PREFERENCE = 0
THC_ONLY = 1
THC_OVER_CBD = 2
EQUAL = 3
CBD_OVER_THC = 4
CBD_ONLY = 5


DESCRIPTOR.enum_types_by_name['Cannabinoid'] = _CANNABINOID
DESCRIPTOR.enum_types_by_name['CannabinoidRatio'] = _CANNABINOIDRATIO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/geo/Address.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/geo/Address.proto',
  package='opencannabis.geo',
  syntax='proto3',
  serialized_options=b'\n\032io.opencannabis.schema.geoH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1eopencannabis/geo/Address.proto\x12\x10opencannabis.geo\x1a\x19gust/core/datamodel.proto\"\xd1\x03\n\x07\x41\x64\x64ress\x12\x34\n\nfirst_line\x18\x01 \x01(\tB \xc2\xb5\x03\x1c\x12\x1a\x46irst line of the address.\x12\x45\n\x0bsecond_line\x18\x02 \x01(\tB0\xc2\xb5\x03,\x12*Second line of the address, if applicable.\x12>\n\x04\x63ity\x18\x03 \x01(\tB0\xc2\xb5\x03,\x12*City or municipality name for the address.\x12S\n\x05state\x18\x04 \x01(\tBD\xc2\xb5\x03@\x12>State that contains the city or municipality for this address.\x12\x41\n\x07zipcode\x18\x05 \x01(\tB0\xc2\xb5\x03,\x12*USPS zipcode associated with this address.\x12q\n\x07\x63ountry\x18\x06 \x01(\tB`\xc2\xb5\x03\\\x12ZCountry code associated with this address (\'US\' or \'USA\' for United States, for instance).B&\n\x1aio.opencannabis.schema.geoH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])




_ADDRESS = _descriptor.Descriptor(
  name='Address',
  full_name='opencannabis.geo.Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='first_line', full_name='opencannabis.geo.Address.first_line', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\034\022\032First line of the address.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='second_line', full_name='opencannabis.geo.Address.second_line', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003,\022*Second line of the address, if applicable.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='city', full_name='opencannabis.geo.Address.city', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003,\022*City or municipality name for the address.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='opencannabis.geo.Address.state', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003@\022>State that contains the city or municipality for this address.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zipcode', full_name='opencannabis.geo.Address.zipcode', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003,\022*USPS zipcode associated with this address.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country', full_name='opencannabis.geo.Address.country', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\\\022ZCountry code associated with this address (\'US\' or \'USA\' for United States, for instance).', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=545,
)

DESCRIPTOR.message_types_by_name['Address'] = _ADDRESS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Address = _reflection.GeneratedProtocolMessageType('Address', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESS,
  '__module__' : 'opencannabis.geo.Address_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.geo.Address)
  })
_sym_db.RegisterMessage(Address)


DESCRIPTOR._options = None
_ADDRESS.fields_by_name['first_line']._options = None
_ADDRESS.fields_by_name['second_line']._options = None
_ADDRESS.fields_by_name['city']._options = None
_ADDRESS.fields_by_name['state']._options = None
_ADDRESS.fields_by_name['zipcode']._options = None
_ADDRESS.fields_by_name['country']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/structs/ProductFlags.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/structs/ProductFlags.proto',
  package='opencannabis.structs',
  syntax='proto3',
  serialized_options=b'\n%io.opencannabis.schema.product.structB\013BaseStructsH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'opencannabis/structs/ProductFlags.proto\x12\x14opencannabis.structs*\xa6\x01\n\x0bProductFlag\x12\x0b\n\x07VISIBLE\x10\x00\x12\n\n\x06HIDDEN\x10\x01\x12\x0b\n\x07PREMIUM\x10\x02\x12\x0c\n\x08\x46\x45\x41TURED\x10\x03\x12\r\n\tEXCLUSIVE\x10\x04\x12\x0c\n\x08IN_HOUSE\x10\x05\x12\x0f\n\x0bLAST_CHANCE\x10\x06\x12\x10\n\x0cLIMITED_TIME\x10\x07\x12\t\n\x05LOCAL\x10\x08\x12\x0b\n\x07\x44\x45LETED\x10\t\x12\x0b\n\x07ON_SALE\x10\x14\x42>\n%io.opencannabis.schema.product.structB\x0b\x42\x61seStructsH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
)

_PRODUCTFLAG = _descriptor.EnumDescriptor(
  name='ProductFlag',
  full_name='opencannabis.structs.ProductFlag',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VISIBLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIDDEN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREMIUM', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXCLUSIVE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IN_HOUSE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LAST_CHANCE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LIMITED_TIME', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCAL', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETED', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ON_SALE', index=10, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=66,
  serialized_end=232,
)
_sym_db.RegisterEnumDescriptor(_PRODUCTFLAG)

ProductFlag = enum_type_wrapper.EnumTypeWrapper(_PRODUCTFLAG)
VISIBLE = 0
HIDDEN = 1
PREMIUM = 2
FEATURED = 3
EXCLUSIVE = 4
IN_HOUSE = 5
LAST_CHANCE = 6
LIMITED_TIME = 7
LOCAL = 8
DELETED = 9
ON_SALE = 20


DESCRIPTOR.enum_types_by_name['ProductFlag'] = _PRODUCTFLAG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/proximity/BluetoothBeacon.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.geo import Location_pb2 as opencannabis_dot_geo_dot_Location__pb2
from opencannabis.geo import Distance_pb2 as opencannabis_dot_geo_dot_Distance__pb2
from opencannabis.temporal import Instant_pb2 as opencannabis_dot_temporal_dot_Instant__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/proximity/BluetoothBeacon.proto',
  package='opencannabis.proximity',
  syntax='proto3',
  serialized_options=b'\n io.opencannabis.schema.proximityH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,opencannabis/proximity/BluetoothBeacon.proto\x12\x16opencannabis.proximity\x1a\x1fopencannabis/geo/Location.proto\x1a\x1fopencannabis/geo/Distance.proto\x1a#opencannabis/temporal/Instant.proto\"\xcf\x01\n\x0f\x42luetoothBeacon\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\r\n\x05major\x18\x02 \x01(\r\x12\r\n\x05minor\x18\x03 \x01(\r\x12,\n\x04seen\x18\x04 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant\x12,\n\x08location\x18\x05 \x01(\x0b\x32\x1a.opencannabis.geo.Location\x12\x34\n\x08\x61\x63\x63uracy\x18\x06 \x01(\x0b\x32\".opencannabis.geo.LocationAccuracyB,\n io.opencannabis.schema.proximityH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_geo_dot_Location__pb2.DESCRIPTOR,opencannabis_dot_geo_dot_Distance__pb2.DESCRIPTOR,opencannabis_dot_temporal_dot_Instant__pb2.DESCRIPTOR,])




_BLUETOOTHBEACON = _descriptor.Descriptor(
  name='BluetoothBeacon',
  full_name='opencannabis.proximity.BluetoothBeacon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='opencannabis.proximity.BluetoothBeacon.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='major', full_name='opencannabis.proximity.BluetoothBeacon.major', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minor', full_name='opencannabis.proximity.BluetoothBeacon.minor', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seen', full_name='opencannabis.proximity.BluetoothBeacon.seen', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='opencannabis.proximity.BluetoothBeacon.location', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accuracy', full_name='opencannabis.proximity.BluetoothBeacon.accuracy', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=383,
)

_BLUETOOTHBEACON.fields_by_name['seen'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_BLUETOOTHBEACON.fields_by_name['location'].message_type = opencannabis_dot_geo_dot_Location__pb2._LOCATION
_BLUETOOTHBEACON.fields_by_name['accuracy'].message_type = opencannabis_dot_geo_dot_Distance__pb2._LOCATIONACCURACY
DESCRIPTOR.message_types_by_name['BluetoothBeacon'] = _BLUETOOTHBEACON
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BluetoothBeacon = _reflection.GeneratedProtocolMessageType('BluetoothBeacon', (_message.Message,), {
  'DESCRIPTOR' : _BLUETOOTHBEACON,
  '__module__' : 'opencannabis.proximity.BluetoothBeacon_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.proximity.BluetoothBeacon)
  })
_sym_db.RegisterMessage(BluetoothBeacon)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/inventory/InventoryLocation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.contact import ContactInfo_pb2 as opencannabis_dot_contact_dot_ContactInfo__pb2
from opencannabis.inventory import InventoryProduct_pb2 as opencannabis_dot_inventory_dot_InventoryProduct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/inventory/InventoryLocation.proto',
  package='opencannabis.inventory',
  syntax='proto3',
  serialized_options=b'\n io.opencannabis.schema.inventoryH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.opencannabis/inventory/InventoryLocation.proto\x12\x16opencannabis.inventory\x1a\x19gust/core/datamodel.proto\x1a&opencannabis/contact/ContactInfo.proto\x1a-opencannabis/inventory/InventoryProduct.proto\"O\n\x14InventoryLocationKey\x12\x14\n\x04uuid\x18\x01 \x01(\tB\x06\xc2\xb5\x03\x02\x08\x02\x12\x0f\n\x07partner\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\"\xd5\x01\n\x11InventoryLocation\x12\x41\n\x03key\x18\x01 \x01(\x0b\x32,.opencannabis.inventory.InventoryLocationKeyB\x06\xc2\xb5\x03\x02\x08\x01\x12;\n\x04type\x18\x02 \x01(\x0e\x32-.opencannabis.inventory.InventoryLocationType\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x32\n\x07\x63ontact\x18\x04 \x01(\x0b\x32!.opencannabis.contact.ContactInfo\"\x89\x01\n\x10InventoryBinding\x12=\n\x07held_by\x18\x01 \x01(\x0b\x32,.opencannabis.inventory.InventoryLocationKey\x12\x36\n\x04item\x18\x02 \x01(\x0b\x32(.opencannabis.inventory.InventoryProduct*B\n\x15InventoryLocationType\x12\n\n\x06RETAIL\x10\x00\x12\r\n\tWAREHOUSE\x10\x01\x12\x0e\n\nPRODUCTION\x10\x02\x42,\n io.opencannabis.schema.inventoryH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_contact_dot_ContactInfo__pb2.DESCRIPTOR,opencannabis_dot_inventory_dot_InventoryProduct__pb2.DESCRIPTOR,])

_INVENTORYLOCATIONTYPE = _descriptor.EnumDescriptor(
  name='InventoryLocationType',
  full_name='opencannabis.inventory.InventoryLocationType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RETAIL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAREHOUSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRODUCTION', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=625,
  serialized_end=691,
)
_sym_db.RegisterEnumDescriptor(_INVENTORYLOCATIONTYPE)

InventoryLocationType = enum_type_wrapper.EnumTypeWrapper(_INVENTORYLOCATIONTYPE)
RETAIL = 0
WAREHOUSE = 1
PRODUCTION = 2



_INVENTORYLOCATIONKEY = _descriptor.Descriptor(
  name='InventoryLocationKey',
  full_name='opencannabis.inventory.InventoryLocationKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='opencannabis.inventory.InventoryLocationKey.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partner', full_name='opencannabis.inventory.InventoryLocationKey.partner', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='opencannabis.inventory.InventoryLocationKey.location', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=267,
)


_INVENTORYLOCATION = _descriptor.Descriptor(
  name='InventoryLocation',
  full_name='opencannabis.inventory.InventoryLocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.inventory.InventoryLocation.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.inventory.InventoryLocation.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.inventory.InventoryLocation.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contact', full_name='opencannabis.inventory.InventoryLocation.contact', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=483,
)


_INVENTORYBINDING = _descriptor.Descriptor(
  name='InventoryBinding',
  full_name='opencannabis.inventory.InventoryBinding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='held_by', full_name='opencannabis.inventory.InventoryBinding.held_by', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item', full_name='opencannabis.inventory.InventoryBinding.item', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=486,
  serialized_end=623,
)

_INVENTORYLOCATION.fields_by_name['key'].message_type = _INVENTORYLOCATIONKEY
_INVENTORYLOCATION.fields_by_name['type'].enum_type = _INVENTORYLOCATIONTYPE
_INVENTORYLOCATION.fields_by_name['contact'].message_type = opencannabis_dot_contact_dot_ContactInfo__pb2._CONTACTINFO
_INVENTORYBINDING.fields_by_name['held_by'].message_type = _INVENTORYLOCATIONKEY
_INVENTORYBINDING.fields_by_name['item'].message_type = opencannabis_dot_inventory_dot_InventoryProduct__pb2._INVENTORYPRODUCT
DESCRIPTOR.message_types_by_name['InventoryLocationKey'] = _INVENTORYLOCATIONKEY
DESCRIPTOR.message_types_by_name['InventoryLocation'] = _INVENTORYLOCATION
DESCRIPTOR.message_types_by_name['InventoryBinding'] = _INVENTORYBINDING
DESCRIPTOR.enum_types_by_name['InventoryLocationType'] = _INVENTORYLOCATIONTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InventoryLocationKey = _reflection.GeneratedProtocolMessageType('InventoryLocationKey', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYLOCATIONKEY,
  '__module__' : 'opencannabis.inventory.InventoryLocation_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.InventoryLocationKey)
  })
_sym_db.RegisterMessage(InventoryLocationKey)

InventoryLocation = _reflection.GeneratedProtocolMessageType('InventoryLocation', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYLOCATION,
  '__module__' : 'opencannabis.inventory.InventoryLocation_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.InventoryLocation)
  })
_sym_db.RegisterMessage(InventoryLocation)

InventoryBinding = _reflection.GeneratedProtocolMessageType('InventoryBinding', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYBINDING,
  '__module__' : 'opencannabis.inventory.InventoryLocation_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.InventoryBinding)
  })
_sym_db.RegisterMessage(InventoryBinding)


DESCRIPTOR._options = None
_INVENTORYLOCATIONKEY.fields_by_name['uuid']._options = None
_INVENTORYLOCATION.fields_by_name['key']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/media/MediaKey.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.media import MediaType_pb2 as opencannabis_dot_media_dot_MediaType__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/media/MediaKey.proto',
  package='opencannabis.media',
  syntax='proto3',
  serialized_options=b'\n\034io.opencannabis.schema.mediaB\014MediaItemKeyH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!opencannabis/media/MediaKey.proto\x12\x12opencannabis.media\x1a\x19gust/core/datamodel.proto\x1a\"opencannabis/media/MediaType.proto\"B\n\x08MediaKey\x12\x36\n\x02id\x18\x01 \x01(\tB*\xc2\xb5\x03\x02\x08\x02\xc2\xb5\x03 J\x1eUnique ID for this media item.\"\x9f\x02\n\x0eMediaReference\x12_\n\x03key\x18\x01 \x01(\x0b\x32\x1c.opencannabis.media.MediaKeyB4\xc2\xb5\x03\x02\x08\x01\xc2\xb5\x03*J(Key being referenced as this media item.\x12J\n\x03uri\x18\x02 \x01(\tB=\xc2\xb5\x03\x39J7URI at which the media item can be consumed/downloaded.\x12`\n\x04type\x18\x03 \x01(\x0b\x32\x1d.opencannabis.media.MediaTypeB3\xc2\xb5\x03/J-Specifies the type of media being referenced.B6\n\x1cio.opencannabis.schema.mediaB\x0cMediaItemKeyH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_media_dot_MediaType__pb2.DESCRIPTOR,])




_MEDIAKEY = _descriptor.Descriptor(
  name='MediaKey',
  full_name='opencannabis.media.MediaKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='opencannabis.media.MediaKey.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\002\302\265\003 J\036Unique ID for this media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=186,
)


_MEDIAREFERENCE = _descriptor.Descriptor(
  name='MediaReference',
  full_name='opencannabis.media.MediaReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.media.MediaReference.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\001\302\265\003*J(Key being referenced as this media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='opencannabis.media.MediaReference.uri', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0039J7URI at which the media item can be consumed/downloaded.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.media.MediaReference.type', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003/J-Specifies the type of media being referenced.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=476,
)

_MEDIAREFERENCE.fields_by_name['key'].message_type = _MEDIAKEY
_MEDIAREFERENCE.fields_by_name['type'].message_type = opencannabis_dot_media_dot_MediaType__pb2._MEDIATYPE
DESCRIPTOR.message_types_by_name['MediaKey'] = _MEDIAKEY
DESCRIPTOR.message_types_by_name['MediaReference'] = _MEDIAREFERENCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MediaKey = _reflection.GeneratedProtocolMessageType('MediaKey', (_message.Message,), {
  'DESCRIPTOR' : _MEDIAKEY,
  '__module__' : 'opencannabis.media.MediaKey_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.media.MediaKey)
  })
_sym_db.RegisterMessage(MediaKey)

MediaReference = _reflection.GeneratedProtocolMessageType('MediaReference', (_message.Message,), {
  'DESCRIPTOR' : _MEDIAREFERENCE,
  '__module__' : 'opencannabis.media.MediaKey_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.media.MediaReference)
  })
_sym_db.RegisterMessage(MediaReference)


DESCRIPTOR._options = None
_MEDIAKEY.fields_by_name['id']._options = None
_MEDIAREFERENCE.fields_by_name['key']._options = None
_MEDIAREFERENCE.fields_by_name['uri']._options = None
_MEDIAREFERENCE.fields_by_name['type']._options = None
# @@protoc_insertion_point(module_scope)



# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.structs`
  ---------------------------
  Generic structures and definitions that are shared across record types.

"""

# `opencannabis.structs`



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/base/Language.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/base/Language.proto',
  package='opencannabis.base',
  syntax='proto3',
  serialized_options=b'\n\033io.opencannabis.schema.baseB\014BaseLanguageH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n opencannabis/base/Language.proto\x12\x11opencannabis.base*J\n\x08Language\x12\x18\n\x14LANGUAGE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x45NGLISH\x10\x01\x12\x0b\n\x07SPANISH\x10\x02\x12\n\n\x06\x46RENCH\x10\x03\x42\x35\n\x1bio.opencannabis.schema.baseB\x0c\x42\x61seLanguageH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
)

_LANGUAGE = _descriptor.EnumDescriptor(
  name='Language',
  full_name='opencannabis.base.Language',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LANGUAGE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENGLISH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPANISH', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FRENCH', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55,
  serialized_end=129,
)
_sym_db.RegisterEnumDescriptor(_LANGUAGE)

Language = enum_type_wrapper.EnumTypeWrapper(_LANGUAGE)
LANGUAGE_UNSPECIFIED = 0
ENGLISH = 1
SPANISH = 2
FRENCH = 3


DESCRIPTOR.enum_types_by_name['Language'] = _LANGUAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
